@@ -1,15 +1,15 @@
-# 
+#
 # This file is part of Config-Model-TkUI
-# 
+#
 # This software is Copyright (c) 2010 by Dominique Dumont.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU Lesser General Public License, Version 2.1, February 1999
-# 
+#
 package Config::Model::Tk::CheckListViewer ;
 BEGIN {
-  $Config::Model::Tk::CheckListViewer::VERSION = '1.308';
+  $Config::Model::Tk::CheckListViewer::VERSION = '1.309';
 }
 
 use strict;
@@ -47,21 +47,23 @@ sub Populate {
     $cw->add_header(View => $leaf)->pack(@fx) ;
 
     my $rt = $cw->Scrolled ( 'ROText',
-			     -scrollbars => 'osoe',
-			     -height => 6,
-			   ) ->pack(@fbe1) ;
+                             -scrollbars => 'osoe',
+                             -height => 6,
+                           ) ->pack(@fbe1) ;
     $rt->tagConfigure('in',-background => 'black', -foreground => 'white') ;
 
     my %h = $leaf->get_checked_list_as_hash ;
     foreach my $c ($leaf->get_choice) {
-	my $tag = $h{$c} ? 'in' : 'out' ;
-	$rt->insert('end', $c."\n" , $tag) ;
+        my $tag = $h{$c} ? 'in' : 'out' ;
+        $rt->insert('end', $c."\n" , $tag) ;
     }
 
     $cw->add_annotation($leaf)->pack(@fx) ;
     $cw->add_summary($leaf)->pack(@fx) ;
 
-    $cw->{value_help_widget} = $cw->add_help(value => '',1)->pack(@fx);
+    my ($help_frame, $help_widget) = $cw->add_help(value => '',1);
+    $help_frame->pack(@fx);
+    $cw->{value_help_widget} = $help_widget ; 
     $cw->set_value_help($leaf->get_checked_list);
 
     $cw->add_description($leaf)->pack(@fx) ;
@@ -69,6 +71,14 @@ sub Populate {
     $cw->add_info_button()->pack(@fxe1, -side => 'left') ;
     $cw->add_editor_button($path)-> pack(@fxe1, -side => 'right') ;
 
+    $cw->ConfigSpecs(
+                     #-fill   => [ qw/SELF fill Fill both/],
+                     #-expand => [ qw/SELF expand Expand 1/],
+                     -relief => [qw/SELF relief Relief groove/ ],
+                     -borderwidth => [qw/SELF borderwidth Borderwidth 2/] ,
+                     DEFAULT => [ qw/SELF/ ],
+           );
+
     $cw->SUPER::Populate($args) ;
 }
 
@@ -76,8 +86,8 @@ sub add_value_help {
     my $cw = shift ;
 
     my $help_frame = $cw->Frame(-relief => 'groove',
-				-borderwidth => 2,
-			       )->pack(@fbe1);
+                                -borderwidth => 2,
+                               )->pack(@fbe1);
     my $leaf = $cw->{leaf} ;
     $help_frame->Label(-text => 'value help: ')->pack(-side => 'left');
     $help_frame->Label(-textvariable => \$cw->{help})
@@ -92,8 +102,8 @@ sub set_value_help {
      $w->delete('0.0','end');
 
      foreach my $v (@set) {
-	 my $value_help = $cw->{leaf}->get_help($v);
-	 $w->insert('end',"$v: ".$value_help."\n") if defined $value_help ;
+         my $value_help = $cw->{leaf}->get_help($v);
+         $w->insert('end',"$v: ".$value_help."\n") if defined $value_help ;
      }
  }
 
@@ -103,7 +113,7 @@ sub get_info {
     my @items = () ;
     my $leaf = $cw->{leaf} ;
     if (defined $leaf->refer_to) {
-	push @items, "refer_to: ".$leaf->refer_to ;
+        push @items, "refer_to: ".$leaf->refer_to ;
     }
     push @items, "ordered: ". ($leaf->ordered ? 'yes' : 'no');
     return $leaf->element_name, @items ;
